-- Author: B. Pankiewicz
-- This code can be used free and without any warranty and only if this comment is not removed
-- Main block connecting RS323 receiver and LED display driver
-- Design reades in RS232 input [RXD_i] using speed rate selected on [SW_i] inputs and then 
-- display following infos at LED display:
-- __________________________________________________________
-- |    LED3   |    LED2  |       LED1       |     LED0     |
-- | RS232 bps | always 0 | received DATA high and low bits |
-- __________________________________________________________

-- Signals description:
-- RS232 receiver with speed selected through SW_i(3)-SW_i(0) switches
-- SIGNALS description:
-- RXD_i - rs232 input signal
-- clk_i - 50MHz input clock
-- rst_i - asynchrons reset
-- led7_an_o - LED display segment selection - LOW level active
-- led7_seg_o - 7-seg LED signals - LOW level active

-- Speed rate coding:
-- | LED display |  bitrate  |   SW_i  |
-- |      F      | 230400bps | 1 1 1 1 | - not working in LAB EA511 due to MINICOM program failure
-- |      E      | 115200bps | 1 1 1 0 |
-- |      D      |  57600bps | 1 1 0 1 |
-- |      C      |  38400bps | 1 1 0 0 |
-- |      B      |  28800bps | 1 0 1 1 |
-- |      A      |  19200bps | 1 0 1 0 |
-- |      9      |  14400bps | 1 0 0 1 |
-- |      8      |   9600bps | 1 0 0 0 |
-- |      7      |   4800bps | 0 1 1 1 |
-- |      6      |   2400bps | 0 1 1 0 |
-- |      5      |   1200bps | 0 1 0 1 |
-- |      4      |    300bps | 0 1 0 0 |
-- |      3      |  not used | 0 0 1 1 |
-- |      2      |  not used | 0 0 1 0 |
-- |      1      |  not used | 0 0 0 1 |
-- |      0      |  not used | 0 0 0 0 |
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity rs232monitor is
    Port ( clk_i : in  STD_LOGIC;
           rst_i : in  STD_LOGIC;
           RXD_i : in  STD_LOGIC;
			  SW_i  : in STD_LOGIC_VECTOR(3 downto 0);
           led7_an_o : out  STD_LOGIC_VECTOR (3 downto 0);
           led7_seg_o : out  STD_LOGIC_VECTOR (7 downto 0));
end rs232monitor;

architecture Behavioral of rs232monitor is

component LED_driver is
    Port (  clk_i : in  STD_LOGIC;
            rst_i : in  STD_LOGIC;
				seg3_i : in  STD_LOGIC_VECTOR (3 downto 0);
				seg2_i : in  STD_LOGIC_VECTOR (3 downto 0);
				seg1_i : in  STD_LOGIC_VECTOR (3 downto 0);
				seg0_i : in  STD_LOGIC_VECTOR (3 downto 0);
				led7_an_o : out  STD_LOGIC_VECTOR (3 downto 0);
				led7_seg_o : out  STD_LOGIC_VECTOR (7 downto 0));
end component;

component rx232 is
    Port ( clk_i : in  STD_LOGIC;
           rst_i : in  STD_LOGIC;
			  RXD_i : in  STD_LOGIC;
			  SW_i  : in STD_LOGIC_VECTOR(3 downto 0);
           data_o : out  STD_LOGIC_VECTOR (7 downto 0);
           status_o : out  STD_LOGIC_VECTOR (3 downto 0));
end component;

signal data :std_logic_vector(7 downto 0);
signal status :std_logic_vector(3 downto 0);

begin

u1: LED_driver
	port map(clk_i,rst_i,status,"0000",data(7 downto 4),data(3 downto 0),led7_an_o,led7_seg_o);
rs:rx232
	port map(clk_i,rst_i,RXD_i,SW_i,data,status);

end Behavioral;

